==> Sim-OPT-0.72.35.tar.gz: optw/modish_defaults.pl <==
@defaults = ( [  2, 2 ], 1, 1, 7, 0.01, 0.99 );



### The above line means: ( [ resolution_x, resolution_y ], $dirvectorsnum, $bounceambnum, $bouncemaxnum, $distgrid, $threshold )

### resolution_x, resolution_y are the gridding values

### The value "$dirvectorsnum" controls the numbers of direction vectors that are used for 
### computing the irradiances at each point of each grid over the surfaces. The values that currently
### can be chosen are 1, 5 and 9. When the points are more than 1, they are evenly distributed 
### on a hemisphere following a geodetic pattern.

### $bounceambnum are the number of the bounces of the diffuse light which are taken into account

# $bouncemaxnum are the number of the bounces of the direct light which are taken into account

# $distgrid is the distance of the grid in meter out of the surfaces which are tamen into account

# $threshold is the threshold under which the changes of shading value are not taken into account. 
# A value of "1" means that if the new shading value is increased instead of decreased in place of the old one,
# the change is not executed.

$computype = "linear";
# TYPES OF CALCULATIONS FOR CALCULATING THE IRRADIANCE FACTORS.
# (SEE SUBROUTINE "compareirrs".)
# OPTIONS: "linear", "quadratic", "root".
# THESE OPTIONS ARE ON THE WAY TO BE DISCARDED AND BECOME OBSOLETE. ONLY "linear will remain".
# WHEN UNSPECIFIED, THE DEFAULT IS "linear".

@calcprocedures = ( "simplified" );
# The options are the following:
# "simplified", "incomplete", "basic", "main", "alternative", "complete", "spreaddiff".
# "main", "alternative", "complete" and "spreaddiff" can be combined with the other options. 
# The others can't. "basic" also can be combined with the others: it can be used in place of "alternative".
# "spreaddiff"c CAN'T BE USED ALONE.
# THE "incomplete" OPTION IS UNSATISFACTORY AND ON THE WAY TO BECOME OBSOLETE.
# MORE THAN ONE OPTION MAY CO-EXIST.
# WITH THE "complete", "alternative" and "main" option, both $bounceambnum and $bouncemaxnum must be assigned a value higher than 0.
# WHEN NO @calcprocedures VALUE IS PRESENT, THE PROGRAM DEFAULTS TO "simplified".

%specularratios = ( reflector => 1 );
#%specularratios = ( totaldirect => 1 );
#%specularratios = ( reflector => 1 );
# THE VALUE OF EACH OF THESE KEY-VALUE PAIRS CONSTITUTES THE PROPORTION OF THE SPECULAR REFLECTIVITY
# IF THE DIFFUSE REFLECTIVITY IS 1 FOR A MATERIAL ATTRIBUTED TO AN OBSTRUCTION. 
# THE KEY OF THE VALUE IS CONSTITUTED BY THE NAME OF THAT MATERIAL.
# IF %specularratios IS UNSPECIFIED, THE VALUE OF THE RATIO FOR EACH MATERIAL OF EACH OBSTRUCTION
# DEFAULTS TO 1.
# If $calcprocedure IS "basic", HOWEVER, THE VALUE OF %specularratios HAVING "totaldirect" AS KEY
# CONSTITUTES THE PROPORTION OF THE TOTAL DIRECT RADIATION IF THE TOTAL DIFFUSE RADIATION IS 1.
# EXAMPLE: %specularratios = ( totaldirect => 1 );
# (SEE SUBROUTINE "pursue").

%skycondition = ( 1=> "clear", 2=> "clear", 3=> "clear", 4=> "clear", 5=> "clear", 6=> "clear", 7=> "clear", 8=> "clear", 
	9=> "clear", 10=> "clear", 11=> "clear", 12=> "clear" );
# PREVAILING CONDITION OF THE SKY FOR EACH MONTH, EXPRESSED WITH ITS NUMBER.
# THE OPTIONS ARE: "clear", "cloudy" and "overcast".
# IF NO VALUE IS SPECIFIED, THE DEFAULT IS "clear".

==> Sim-OPT-0.72.37.tar.gz: optw/modish_defaults.pl <==
@defaults = ( [  2, 2 ], 1, 1, 7, 0.01, 0.99 );



### The above line means: ( [ resolution_x, resolution_y ], $dirvectorsnum, $bounceambnum, $bouncemaxnum, $distgrid, $threshold )

### resolution_x, resolution_y are the gridding values

### The value "$dirvectorsnum" controls the numbers of direction vectors that are used for 
### computing the irradiances at each point of each grid over the surfaces. The values that currently
### can be chosen are 1, 5 and 9. When the points are more than 1, they are evenly distributed 
### on a hemisphere following a geodetic pattern.

### $bounceambnum are the number of the bounces of the diffuse light which are taken into account

# $bouncemaxnum are the number of the bounces of the direct light which are taken into account

# $distgrid is the distance of the grid in meter out of the surfaces which are tamen into account

# $threshold is the threshold under which the changes of shading value are not taken into account. 
# A value of "1" means that if the new shading value is increased instead of decreased in place of the old one,
# the change is not executed.

#$computype = "linear";
# TYPES OF CALCULATIONS FOR CALCULATING THE IRRADIANCE FACTORS.
# (SEE SUBROUTINE "compareirrs".)
# OPTIONS: "linear", "quadratic", "root".
# THE LATTER TWO OPTIONS ARE OBSOLETE. ONLY "linear will remain".
# WHEN UNSPECIFIED, THE DEFAULT IS "linear".

@calcprocedures = ( "complete" );
# Some options are the following:
# "simplified", "incomplete", "basic", "main", "alternative", "complete", "maincomplete", spreaddiff".
# THEY DIFFER IN HOW DIRECT RADIATION IS DISTINGUISHED FROM INDIRECT RADIATION.
# ANOTHER OPTION IS "unified", WHICH HAS AN INFLUENCE ON THE WAY THE IRRADIANCE RATIOS ARE CALCULATED.
# ONE MORE OPTION IS "wipeins", WHiCH WIPES OUT THE INSOLATION VALUES IN THE ISH FILES AFTER THE NEW
# SHADING VALUES HAVE BEEN COMPUTED.
# "alternative", "basic", "spreaddiff" AND HAVE BEEN DISCARDED AND BECOME OBSOLETE.
# "basic" COULD BE ONLY USED IN PLACE OF "alternative".
# "spreaddiff" CAN'T BE USED ALONE.
# WITH THE "complete" AND "main" OPTIONS, BOTH $bounceambnum AND $bouncemaxnum MUST BE ASSIGNED A VALUE OTHER THAN 0.
# WHEN NO @calcprocedures VALUE IS PRESENT, THE PROGRAM DEFAULTS TO "simplified".

%specularratios = ( reflector => 0 );
#%specularratios = ( totaldirect => 1 );
#%specularratios = ( reflector => 1 );
# THE VALUE OF EACH OF THESE KEY-VALUE PAIRS CONSTITUTES THE PROPORTION OF THE SPECULAR REFLECTIVITY
# IF THE DIFFUSE REFLECTIVITY IS 1 FOR A MATERIAL ATTRIBUTED TO AN OBSTRUCTION. 
# THE KEY OF THE VALUE IS CONSTITUTED BY THE NAME OF THAT MATERIAL.
# IF %specularratios IS UNSPECIFIED, THE VALUE OF THE RATIO FOR EACH MATERIAL OF EACH OBSTRUCTION
# DEFAULTS TO 1.
# If $calcprocedure IS "basic", HOWEVER, THE VALUE OF %specularratios HAVING "totaldirect" AS KEY
# CONSTITUTES THE PROPORTION OF THE TOTAL DIRECT RADIATION IF THE TOTAL DIFFUSE RADIATION IS 1.
# EXAMPLE: %specularratios = ( totaldirect => 1 );
# (SEE SUBROUTINE "pursue").

%skycondition = ( 1=> "clear", 2=> "clear", 3=> "clear", 4=> "clear", 5=> "clear", 6=> "clear", 7=> "clear", 8=> "clear", 
	9=> "clear", 10=> "clear", 11=> "clear", 12=> "clear" );
# PREVAILING CONDITION OF THE SKY FOR EACH MONTH, EXPRESSED WITH ITS NUMBER.
# THE OPTIONS ARE: "clear", "cloudy" and "overcast".
# IF NO VALUE IS SPECIFIED, THE DEFAULT IS "clear".
